@@ -63,3 +63,5 @@ status_requests_body_error = "requests body error"
 html_generate_no_data_tag = "record is None"
 # add command
 add_command_exception_tag = "command value type should be as method or function"
+# argparse
+argparse_get_wrong_data = "argparse receive wrong data"
